@@ -19,6 +19,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+
+#include <glib/gi18n-lib.h>
 #include "util.h"
 #include "xutils.h"
 #include "private.h"
@@ -248,7 +251,7 @@ wnck_set_client_type (WnckClientType ewmh_sourceindication_client_type)
 }
 
 WnckClientType
-_wnck_get_client_type ()
+_wnck_get_client_type (void)
 {
   /* If the type hasn't been set yet, use the default--treat it as a
    * normal application.
