@@ -77,7 +77,6 @@ typedef enum
   WNCK_WINDOW_DESKTOP,      /* desktop background */
   WNCK_WINDOW_DOCK,         /* panel */
   WNCK_WINDOW_DIALOG,       /* dialog */
-  WNCK_WINDOW_MODAL_DIALOG, /* modal dialog */
   WNCK_WINDOW_TOOLBAR,      /* tearoff toolbar */
   WNCK_WINDOW_MENU,         /* tearoff menu */
   WNCK_WINDOW_UTILITY,      /* palette/toolbox window */
@@ -175,6 +174,8 @@ const char* wnck_window_get_session_id        (WnckWindow *window);
 const char* wnck_window_get_session_id_utf8   (WnckWindow *window);
 int         wnck_window_get_pid               (WnckWindow *window);
 gint        wnck_window_get_sort_order        (WnckWindow *window);
+void        wnck_window_set_sort_order        (WnckWindow *window, 
+						gint order);
 
 WnckWindowType wnck_window_get_window_type    (WnckWindow *window);
 void           wnck_window_set_window_type    (WnckWindow *window,
